@@ -47,5 +47,5 @@ from laygo2.object import *
 from laygo2.object.database import *
 from laygo2.object.grid import *
 from laygo2.object.physical import *
-from laygo2.object.template import *
-from laygo2.object.routing import *
+from laygo2.object.template.core import *
+from laygo2.object.template.routing import *
